@@ -23,9 +23,7 @@
 #include <memory>
 #include <string>
 
-namespace mobius
-{
-namespace database
+namespace mobius::database
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief sqlite3 database class
@@ -67,7 +65,6 @@ private:
   std::shared_ptr <database_impl> impl_;
 };
 
-} // namespace database
-} // namespace mobius
+} // namespace mobius::database
 
 #endif
